@@ -7,7 +7,7 @@
 #
 #  Copyright  1996, Cees de Groot.
 #  Copyright  2000, Taketoshi Sano
-#  Copyright  2006-2009, Agustin Martin
+#  Copyright  2006-2015, Agustin Martin
 # --------------------------------------------------------------------------------
 
 package LinuxDocTools;
@@ -414,12 +414,18 @@ sub process_options {
   # Normalize language string
   $global->{language} = Any2ISO($global->{language});
 
-  # Setup the SGML environment.`iso-entites' sub directory will be removed for Debian package
-  # and entities from Debian sgml-data package used if present (first entry below).
-  my @sgmlcatalogs = ( "$main::prefix/share/sgml/entities/sgml-iso-entities-8879.1986/catalog",
-		       "$main::prefix/share/sgml/iso-entities-8879.1986/iso-entities.cat",
-		       "$main::DataDir/linuxdoc-tools.catalog",
-		       "/etc/sgml.catalog");
+  # Setup the SGML environment.
+  my @sgmlcatalogs =
+    (# SGML iso-entities catalog location in Debian sgml-data package
+     "$main::isoentities_prefix/share/sgml/entities/sgml-iso-entities-8879.1986/catalog",
+     # SGML iso-entities catalog location in ArchLinux, Fedora and Gentoo
+     "$main::isoentities_prefix/share/sgml/sgml-iso-entities-8879.1986/catalog",
+     # SGML iso-entities catalog location when installed from linuxdoc-tools
+     "$main::isoentities_prefix/share/sgml/iso-entities-8879.1986/iso-entities.cat",
+     # dtd/catalog for SGML-Tools
+     "$main::DataDir/linuxdoc-tools.catalog",
+     # The super catalog
+     "/etc/sgml/catalog");
 
   @sgmlcatalogs = ($ENV{SGML_CATALOG_FILES}, @sgmlcatalogs) if defined $ENV{SGML_CATALOG_FILES};
 
